package modconfig

import "github.com/hashicorp/hcl/v2"

// ResourceMetadata is a struct containing additional data
// about each resource, used to populate the introspection tables
type ResourceMetadata struct {
	// required to allow partial decoding
	ResourceMetadataRemain hcl.Body `hcl:",remain" json:"-"`

	ResourceName string `json:"resource_name"`
	// mod short name
	ModName          string `json:"mod_name"`
	FileName         string `json:"file_name"`
	StartLineNumber  int    `json:"start_line_number"`
	EndLineNumber    int    `json:"end_line_number"`
	IsAutoGenerated  bool   `json:"auto_generated"`
	SourceDefinition string `json:"source_definition"`
	Anonymous        bool   `json:"is_anonymous"`
	ModFullName      string `json:"-"`
}

// SetMod sets the mod name and mod short name
func (m *ResourceMetadata) SetMod(mod *Mod) {
	// if the mod is the auto-generated default workspace mod, do not save in metadata
	if mod.IsDefaultMod() {
		return
	}
	m.ModName = mod.ShortName
	m.ModFullName = mod.FullName
}

func (m *ResourceMetadata) Clone() ResourceMetadata {
	return ResourceMetadata{
		ResourceName:     m.ResourceName,
		ModName:          m.ModName,
		FileName:         m.FileName,
		StartLineNumber:  m.StartLineNumber,
		EndLineNumber:    m.EndLineNumber,
		IsAutoGenerated:  m.IsAutoGenerated,
		SourceDefinition: m.SourceDefinition,
		ModFullName:      m.ModFullName,
		Anonymous:        m.Anonymous,
	}
}
